@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use Cwd;
 use Carp ();
-use Module::CPANfile::Environment ();
+use Module::CPANfile::Environment;
 use Module::CPANfile::Result;
 
-our $VERSION = '0.9034';
+our $VERSION = '0.9035';
 
 sub new {
     my($class, $file) = @_;
@@ -15,9 +15,9 @@ sub new {
 
 sub load {
     my($proto, $file) = @_;
+
     my $self = ref $proto ? $proto : $proto->new;
-    $self->{file} = $file || "cpanfile";
-    $self->parse;
+    $self->parse($file || Cwd::abs_path('cpanfile'));
     $self;
 }
 
@@ -29,10 +29,15 @@ sub save {
 }
 
 sub parse {
-    my $self = shift;
+    my($self, $file) = @_;
 
-    my $file = Cwd::abs_path($self->{file});
-    $self->{result} = Module::CPANfile::Environment::parse($file) or die $@;
+    my $code = do {
+        open my $fh, "<", $file or die "$file: $!";
+        join '', <$fh>;
+    };
+
+    my $env = Module::CPANfile::Environment->new($file);
+    $self->{result} = $env->parse($code) or die $@;
 }
 
 sub from_prereqs {
@@ -62,7 +67,18 @@ sub feature {
     });
 }
 
-sub prereqs { shift->prereq }
+sub prereq { shift->prereqs }
+
+sub prereqs {
+    my $self = shift;
+    require CPAN::Meta::Prereqs;
+    CPAN::Meta::Prereqs->new($self->prereq_specs);
+}
+
+sub effective_prereqs {
+    my($self, $features) = @_;
+    $self->prereqs_with(@{$features || []});
+}
 
 sub prereqs_with {
     my($self, @feature_identifiers) = @_;
@@ -73,12 +89,6 @@ sub prereqs_with {
     $prereqs->with_merged_prereqs(\@others);
 }
 
-sub prereq {
-    my $self = shift;
-    require CPAN::Meta::Prereqs;
-    CPAN::Meta::Prereqs->new($self->prereq_specs);
-}
-
 sub prereq_specs {
     my $self = shift;
     $self->{result}{spec};
@@ -224,9 +234,9 @@ Returns a hash reference that should be passed to C<< CPAN::Meta::Prereqs->new >
 
 Returns a list of features available in the cpanfile as L<CPAN::Meta::Feature>.
 
-=item prereqs_with(@identifiers)
+=item prereqs_with(@identifiers), effective_prereqs(\@identifiers)
 
-Retuens L<CPAN::Meta::Prereqs> object, with merged prereqs for
+Returns L<CPAN::Meta::Prereqs> object, with merged prereqs for
 features identified with the C<@identifiers>.
 
 =item to_string($include_empty)
